==> eiffelstudio-18.07.10.1981.tar: F_code/C4/ev176.c <==
/*
 * Code for class EV_STOCK_PIXMAPS_IMP
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ev176.h"
#include "ev_c_util.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EV_STOCK_PIXMAPS_IMP}.information_pixmap */
EIF_REFERENCE F433_3832 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLR(2,tr3);
	RTLR(3,Current);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1018, 0x00).id, 1018, _OBJSIZ_6_3_0_1_0_0_0_0_);
	tr2 = RTLNS(eif_new_type(770, 0x00).id, 770, _OBJSIZ_0_1_0_1_0_1_0_0_);
	tr3 = RTMS_EX_H("gtk-dialog-info",15,2003234927);
	F771_5102(RTCW(tr2), tr3);
	tr2 = F433_3841(Current, tr2);
	F1019_8669(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTLE;
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.error_pixmap */
EIF_REFERENCE F433_3833 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLR(2,tr3);
	RTLR(3,Current);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1018, 0x00).id, 1018, _OBJSIZ_6_3_0_1_0_0_0_0_);
	tr2 = RTLNS(eif_new_type(770, 0x00).id, 770, _OBJSIZ_0_1_0_1_0_1_0_0_);
	tr3 = RTMS_EX_H("gtk-dialog-error",16,1795811698);
	F771_5102(RTCW(tr2), tr3);
	tr2 = F433_3841(Current, tr2);
	F1019_8669(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTLE;
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.warning_pixmap */
EIF_REFERENCE F433_3834 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLR(2,tr3);
	RTLR(3,Current);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1018, 0x00).id, 1018, _OBJSIZ_6_3_0_1_0_0_0_0_);
	tr2 = RTLNS(eif_new_type(770, 0x00).id, 770, _OBJSIZ_0_1_0_1_0_1_0_0_);
	tr3 = RTMS_EX_H("gtk-dialog-warning",18,251057767);
	F771_5102(RTCW(tr2), tr3);
	tr2 = F433_3841(Current, tr2);
	F1019_8669(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTLE;
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.default_window_icon */
EIF_REFERENCE F433_3840 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,tr1);
	RTLR(1,Result);
	RTLR(2,loc1);
	RTLIU(3);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1018, 0x00).id, 1018, _OBJSIZ_6_3_0_1_0_0_0_0_);
	F947_7628(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	loc1 = *(EIF_REFERENCE *)(RTCW(Result) + _REFACS_3_);
	F1232_11918(RTCW(loc1));
	RTLE;
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.pixmap_from_stock_id */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
EIF_REFERENCE F433_3841 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE EIF_VOLATILE loc2 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN EIF_VOLATILE loc3 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_POINTER  EIF_VOLATILE tp1;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	RTXD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLR(4,loc2);
	RTLR(5,saved_except);
	RTLIU(6);
	RTXSLS;
	
	RTEV;
	RTGC;
	RTE_T
	if ((EIF_BOOLEAN) !loc3) {
		loc1 = (EIF_REFERENCE) arg1;
		tr1 = RTLNS(eif_new_type(964, 0x00).id, 964, _OBJSIZ_3_0_0_0_0_0_0_0_);
		F947_7628(RTCW(tr1));
		Result = (EIF_REFERENCE) tr1;
		loc2 = *(EIF_REFERENCE *)(RTCW(Result) + _REFACS_1_);
		loc2 = RTRV(eif_new_type(1076, 0x00), loc2);
		RTCT0(NULL, EX_CHECK);
		if ((EIF_BOOLEAN)(loc2 != NULL)) {
			RTCK0;
		} else {
			RTCF0;
		}
		tp1 = *(EIF_POINTER *)(RTCW(loc1)+ _PTROFF_0_1_0_1_0_0_);
		F1077_9394(RTCW(loc2), tp1);
	} else {
		tr1 = RTLNS(eif_new_type(964, 0x00).id, 964, _OBJSIZ_3_0_0_0_0_0_0_0_);
		F947_7628(RTCW(tr1));
		Result = (EIF_REFERENCE) tr1;
	}
	RTE_E
	RTXSC;
	loc3 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTER;
	/* NOTREACHED */
	RTE_EE
	RTEOK;
	RTLE;
	return Result;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {EV_STOCK_PIXMAPS_IMP}.no_cursor_xpm */
EIF_POINTER F433_3854 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) no_cursor_xpm();
	
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.sizenesw_cursor_xpm */
EIF_POINTER F433_3856 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) sizenesw_cursor_xpm();
	
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.sizenwse_cursor_xpm */
EIF_POINTER F433_3858 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) sizenwse_cursor_xpm();
	
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.sizewe_cursor_xpm */
EIF_POINTER F433_3859 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) sizewe_cursor_xpm();
	
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.uparrow_cursor_xpm */
EIF_POINTER F433_3861 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) uparrow_cursor_xpm();
	
	return Result;
}

void EIF_Minit176 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C4/ev176.c <==
/*
 * Code for class EV_STOCK_PIXMAPS_IMP
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ev176.h"
#include "ev_c_util.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EV_STOCK_PIXMAPS_IMP}.information_pixmap */
EIF_REFERENCE F214_3529 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLR(2,Current);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	Result = RTLNS(eif_new_type(1021, 0x00).id, 1021, _OBJSIZ_6_3_0_1_0_0_0_0_);
	tr1 = RTLNS(eif_new_type(776, 0x00).id, 776, _OBJSIZ_0_1_0_1_0_1_0_0_);
	tr2 = RTMS_EX_H("gtk-dialog-info",15,2003234927);
	F777_5165(RTCW(tr1), tr2);
	tr1 = F214_3538(Current, tr1);
	F1022_8677(RTCW(Result), tr1);
	RTLE;
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.error_pixmap */
EIF_REFERENCE F214_3530 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLR(2,Current);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	Result = RTLNS(eif_new_type(1021, 0x00).id, 1021, _OBJSIZ_6_3_0_1_0_0_0_0_);
	tr1 = RTLNS(eif_new_type(776, 0x00).id, 776, _OBJSIZ_0_1_0_1_0_1_0_0_);
	tr2 = RTMS_EX_H("gtk-dialog-error",16,1795811698);
	F777_5165(RTCW(tr1), tr2);
	tr1 = F214_3538(Current, tr1);
	F1022_8677(RTCW(Result), tr1);
	RTLE;
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.warning_pixmap */
EIF_REFERENCE F214_3531 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLR(2,Current);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	Result = RTLNS(eif_new_type(1021, 0x00).id, 1021, _OBJSIZ_6_3_0_1_0_0_0_0_);
	tr1 = RTLNS(eif_new_type(776, 0x00).id, 776, _OBJSIZ_0_1_0_1_0_1_0_0_);
	tr2 = RTMS_EX_H("gtk-dialog-warning",18,251057767);
	F777_5165(RTCW(tr1), tr2);
	tr1 = F214_3538(Current, tr1);
	F1022_8677(RTCW(Result), tr1);
	RTLE;
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.default_window_icon */
EIF_REFERENCE F214_3537 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Result);
	RTLR(1,loc1);
	RTLIU(2);
	
	RTGC;
	Result = RTLNS(eif_new_type(1021, 0x00).id, 1021, _OBJSIZ_6_3_0_1_0_0_0_0_);
	F954_7721(RTCW(Result));
	loc1 = *(EIF_REFERENCE *)(RTCW(Result) + _REFACS_3_);
	F1238_12010(RTCW(loc1));
	RTLE;
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.pixmap_from_stock_id */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
EIF_REFERENCE F214_3538 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE EIF_VOLATILE loc2 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN EIF_VOLATILE loc3 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_POINTER  EIF_VOLATILE tp1;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	RTXD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLR(4,loc2);
	RTLR(5,saved_except);
	RTLIU(6);
	RTXSLS;
	
	RTEV;
	RTGC;
	RTE_T
	if ((EIF_BOOLEAN) !loc3) {
		loc1 = (EIF_REFERENCE) arg1;
		tr1 = RTLNS(eif_new_type(971, 0x00).id, 971, _OBJSIZ_3_0_0_0_0_0_0_0_);
		F954_7721(RTCW(tr1));
		Result = (EIF_REFERENCE) tr1;
		loc2 = *(EIF_REFERENCE *)(RTCW(Result) + _REFACS_1_);
		loc2 = RTRV(eif_new_type(1080, 0x00), loc2);
		RTCT0("pixbuf_imp /= Void", EX_CHECK);
		if ((EIF_BOOLEAN)(loc2 != NULL)) {
			RTCK0;
		} else {
			RTCF0;
		}
		tp1 = *(EIF_POINTER *)(RTCW(loc1)+ _PTROFF_0_1_0_1_0_0_);
		F1081_9458(RTCW(loc2), tp1);
	} else {
		tr1 = RTLNS(eif_new_type(971, 0x00).id, 971, _OBJSIZ_3_0_0_0_0_0_0_0_);
		F954_7721(RTCW(tr1));
		Result = (EIF_REFERENCE) tr1;
	}
	RTE_E
	RTXSC;
	loc3 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTER;
	/* NOTREACHED */
	RTE_EE
	RTEOK;
	RTLE;
	return Result;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {EV_STOCK_PIXMAPS_IMP}.no_cursor_xpm */
EIF_POINTER F214_3551 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) no_cursor_xpm();
	
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.sizenesw_cursor_xpm */
EIF_POINTER F214_3553 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) sizenesw_cursor_xpm();
	
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.sizenwse_cursor_xpm */
EIF_POINTER F214_3555 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) sizenwse_cursor_xpm();
	
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.sizewe_cursor_xpm */
EIF_POINTER F214_3556 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) sizewe_cursor_xpm();
	
	return Result;
}

/* {EV_STOCK_PIXMAPS_IMP}.uparrow_cursor_xpm */
EIF_POINTER F214_3558 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	
	Result = (EIF_POINTER) uparrow_cursor_xpm();
	
	return Result;
}

void EIF_Minit176 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
